/*
 *  The ManaPlus Client
 *  Copyright (C) 2009  The Mana World Development Team
 *  Copyright (C) 2009-2010  The Mana Developers
 *  Copyright (C) 2011-2013  The ManaPlus Developers
 *
 *  This file is part of The ManaPlus Client.
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef EATHENA_GUILDTAB_H
#define EATHENA_GUILDTAB_H

#include "net/ea/gui/guildtab.h"

namespace EAthena
{

/**
 * A tab for a guild chat channel.
 */
class GuildTab : public Ea::GuildTab
{
    public:
        explicit GuildTab(const Widget2 *const widget);

        A_DELETE_COPY(GuildTab)

        ~GuildTab();
};

}  // namespace EAthena

#endif  // EATHENA_GUILDTAB_H
